.. :changelog:

Release History
---------------

0.1.2 (2014-4-4)
++++++++++++++++

- Documentation reorganization

**Bug Fixes**

- Fixed unicode encode/decode errors

0.1.1 (2014-4-3)
++++++++++++++++

- PyPy-c v2.2 now support

**Bug Fixes**

- Quick fix PyPI distribution (huge package sizes)
- MANIFEST.in now does it job
- Assorted fixes with methods and scope

0.1.0 (2014-4-2)
++++++++++++++++

- GTranslate is taken on PyPI.
- Name changed to py-translate
- Distributed through PyPI and Wheel
- More documentation and autoparsing for module functions
- Seperated into logical modules in a package rather than one executable __main__.py

0.0.0 (2014-3-31)
+++++++++++++++++

- Support for Python 2.7 and 3.x
- Sphinx Documentation hosted
- Travis CI build passed!
- Source released on Github
